#include <kernel/include.h>
#include <drivers/serial/serial.h>
#include <drivers/lcd/define.h>
#include <drivers/rtc/rtc.h>
#include <drivers/key/key.h>
#include <drivers/fnd/fnd.h>
//#include <drivers/textlcd/textlcd.h>

#include "mainimg.h"
#include "main0.h"
#include "img0.h"
#include "img0_0_36x64.h"
#include "img0_0_o.h"
#include "img0_1_88x72.h"
#include "img0_1_o.h"
#include "img0_2_56x48.h"
#include "img0_2_o.h"
#include "img1.h"
#include "loading_140x28.h"

#define ON	1
#define OFF	0



char task_key_queue[4] = {0xf, 0xf, 0xf, 0xf};
int selecting = 0;


void task_key();
void task_cyber_room();
void task_coffee_maker();
void task_news_reader();


int C_Entry()
{
	rtc_init(7, 0, 0);

	Arch_Init();
	Kern_Init();
	Kern_IOSubBuild();

	Kern_ThreadCreate(1, &task_key, 1, 0);
	Kern_ThreadCreate(2, &task_cyber_room, 2, 0);
	Kern_ThreadCreate(3, &task_coffee_maker, 3, 0);
//	Kern_ThreadCreate(4, &task_news_reader, 4, 0);

	lcd_putpic(loading, 250, 226, 140, 28, 0x10);
	lcd_putpic(mainimg, 0, 0, 640, 480, 0x11);

	OSTimer0_IRQ_Init();
	Kern_Sched();

	while(1) {;}

	return 0;
}

void display_menu(void)
{
	SerialOutputString("## menu ## ");
	switch (selecting) {
		case 2:
			SerialOutputString("<cyber room>   coffee maker \n");
			break;
		case 3:
			SerialOutputString(" cyber room   <coffee maker>\n");
			break;
		default:
			SerialOutputString(" cyber room    coffee maker \n");
			break;
	}
	SerialOutputString("(8):[menu] (4):[cyber_room] (0):[coffee_maker]\n");
	SerialOutputString("(9):-      (5):up           (1):premium\n");
	SerialOutputString("(A):-      (6):down         (2):normal\n");
	SerialOutputString("(B):-      (7):-            (3):cancle\n");
	SerialOutputString("push key button!\n");
}

char key_wait(int task_no)
{
	char keyin;

	while (task_key_queue[task_no] == 0xf) ;
	keyin = task_key_queue[task_no];
	task_key_queue[task_no] = 0xf;

	return keyin;
}

void task_key(void)
{
	char keyin;

	for (;;) {
		keyin = key_read();
		switch (keyin) {
			case 0x0:
				lcd_putpic(loading, 250, 226, 140, 28, 0x00);
				lcd_putbmp(img1, 160, 120, 320, 240, 0x10);
				selecting = 3;
				display_menu();
				break;
			case 0x4:
				lcd_putpic(loading, 250, 226, 140, 28, 0x00);
				lcd_putbmp(img0, 160, 120, 320, 240, 0x10);
				selecting = 2;
				display_menu();
				break;
			case 0x8:
				lcd_putpic(loading, 250, 226, 140, 28, 0x00);
				lcd_putpic(main0, 160, 120, 320, 240, 0x10);
				selecting = 0;
				display_menu();
				break;
			default:
				task_key_queue[selecting] = keyin;
				break;
		}
	}
}

void task_cyber_room(void)
{
	char no;

	int toggle0, toggle1, toggle2;
	toggle0 = OFF;
	toggle1 = OFF;
	toggle2 = OFF;

	for (;;) {
		no = key_wait(2);

		switch (no) {
			case 0x5:	// light
				if (toggle0 == OFF) {
					SerialOutputString("light on!\n");
					lcd_putpic(img0_0_o, 160+120, 120+0, 36, 64, 0x00);
					toggle0 = ON;
				}
				else {
					SerialOutputString("light off!\n");
					lcd_putbmp(img0_0, 160+120, 120+0, 36, 64, 0x00);
					toggle0 = OFF;
				}
				break;
			case 0x6:	// audio
				if (toggle1 == OFF) {
					SerialOutputString("audio on!\n");
					lcd_putbmp(img0_1_o, 160+50, 120+168, 88, 72, 0x00);
					toggle1 = ON;
				}
				else {
					SerialOutputString("audio off!\n");
					lcd_putbmp(img0_1, 160+50, 120+168, 88, 72, 0x00);
					toggle1 = OFF;
				}
				break;
			case 0x7:	// television
				if (toggle2 == OFF) {
					SerialOutputString("television on!\n");
					lcd_putbmp(img0_2_o, 160+202, 120+98, 56, 48, 0x00);
					toggle2 = ON;
				}
				else {
					SerialOutputString("television off!\n");
					lcd_putbmp(img0_2, 160+202, 120+98, 56, 48, 0x00);
					toggle2 = OFF;
				}
				break;
			default:
				SerialOutputString("invaild key!\n");
				break;
		}
	}
}

void task_coffee_maker(void)
{
	char no;

	for (;;) {
		no = key_wait(3);

		switch (no) {
			case 0x1:
				SerialOutputString("making premium coffee! waiting for 30 second!\n");
				rtc_alarm_init(0, 0, 30);
				break;
			case 0x2:
				SerialOutputString("making normal coffee! waiting for 15 second!\n");
				rtc_alarm_init(0, 0, 15);
				break;
			case 0x3:
				SerialOutputString("coffee order cancle!\n");
				rtc_alarm_release();
				break;
			default:
				SerialOutputString("invaild key!\n");
				break;
		}
	}
}

#if 0
void task_news_reader(void)
{
	int i;
	char row_buffer1[50] = "ELFOS TIMES - 2007. 11. 08 (THU)";
	char row_buffer2[500] = "[Blackwater boss agrees to meet grieving mom] Donna Zovko has sought answers for her son since he was mutilated in Iraq in 2004. The devout Catholic told CNN.com she'd be willing to trade in a meeting with the pope to meet her son's boss. Now, Blackwater chairman Erik Prince says he'll give her that opportunity";
	char *row_one = row_buffer1;
	char *row_two = row_buffer2;
	struct strcommand_varible strcommand;

	strcommand.rows = 0;
	strcommand.nfonts = 0;
	strcommand.display_enable = 1;
	strcommand.cursor_enable = 0;
	strcommand.nblink = 0;
	strcommand.set_screen = 1;
	strcommand.set_rightshit= 0;
	strcommand.increase = 1;
	strcommand.nshift = 0;
	strcommand.pos = 10;
	strcommand.command = 1;
	strcommand.strlength = 16;	
	

	clear_display();
	delayed(1000);

	strcommand.pos = 0;
	set_ddram_address((int)strcommand.pos);

	write_string(0, row_buffer1, 32);
	delayed(1000);	
	
	strcommand.pos = 40;
	set_ddram_address((int)strcommand.pos);

	write_string(1, row_buffer1, 32);
	delayed(1000);	
/*
	for(i = 0;i < 16;i++) {
		if(row_two[i] == '\0') break;
		memcpy(&strcommand.buf[0],&row_two[i],1);
		writebyte(strcommand.buf[0]);
	}
	delayed(1000);
*/
	for(;;){
		cusrsor_shit((int)strcommand.set_screen,(int)strcommand.set_rightshit);
		delayed(200);
	}
}
#endif
